@@ -32,16 +32,17 @@ import  fov
 params = {#'backend': 'png',
                         'axes.linewidth': 1.5,
                         'axes.labelsize': 24,
-                        'axes.font': 'sans-serif',
+                        'font.family': 'sans-serif',
                         #'axes.fontweight' : 'bold',
-                        'text.fontsize': 22,
+                        'font.size': 22,
                         'legend.fontsize': 14,
                         'xtick.labelsize': 16,
                         'ytick.labelsize': 16,
                         'text.usetex': False,
                         #'font.family': 'Palatino'
                         }
-plt.rcParams.update(params)
+if got_mpl:
+    plt.rcParams.update(params)
 
 #try:
 #    plt.rcParams.update({'font.family': 'Palatino'})
